"""UI utilities for Gradio applications."""

from cgc_common.ui.gradio import (
    CSSVariables,
    GradioTheme,
    build_header,
    default_css_variables,
    LOGO_SVG,
)

__all__ = [
    "CSSVariables",
    "GradioTheme",
    "build_header",
    "default_css_variables",
    "LOGO_SVG",
]
